@@ -1,6 +1,6 @@
 # This file is part of sympy2c.
 #
-# Copyright (C) 2013-2021 ETH Zurich, Institute for Particle and Astrophysics and SIS
+# Copyright (C) 2013-2022 ETH Zurich, Institute for Particle and Astrophysics and SIS
 # ID.
 #
 # This program is free software: you can redistribute it and/or modify it under the
@@ -88,36 +88,3 @@ def create_curry_class(n_fixed_args):
     )
 
     return class_name, code
-
-
-if __name__ == "__main__":
-
-    print("#include <cstdio>")
-    base_class_name, base_class_decl, class_name, class_decl = create_curry_class(
-        ["x", "y", "z"], ["x", "z"]
-    )
-    print(base_class_decl)
-    print(class_decl)
-    print(
-        r"""
-
-    double add3(double x, double y, double z) { return x + y + z; };
-
-    double integrate(Function1Ary *f) {
-        double sum = 0.5 * (*f)(0) + 0.5 * (*f)(1);
-        double h = 0.1;
-        for (int i=1; i<10; i++)
-            sum += (*f)(i * h);
-        return(h * sum);
-    }
-
-    int main()
-    {
-        Curry_3_0_2 f(add3, 1, 3);
-        std::printf("should be 4: %lf\n", f(0));
-        std::printf("should be 5: %lf\n", f(1));
-        std::printf("should be 4.5: %lf\n", integrate(&f));
-
-    }
-    """
-    )
