@@ -1,6 +1,6 @@
 # This file is part of sympy2c.
 #
-# Copyright (C) 2013-2021 ETH Zurich, Institute for Particle and Astrophysics and SIS
+# Copyright (C) 2013-2022 ETH Zurich, Institute for Particle and Astrophysics and SIS
 # ID.
 #
 # This program is free software: you can redistribute it and/or modify it under the
@@ -332,7 +332,7 @@ def generate_solve_split(id_, all_traces, splits, N):
     )
 
     yield dedent(
-        fr"""
+        rf"""
 
     std::vector<std::vector<unsigned int> > _call_counts_{id_};
     static unsigned int  _next_solver_{id_}[{len(splits) + 1}] = {{0}};
@@ -953,7 +953,7 @@ def create_check(id_, M, expression_to_c, state_vars):
             if M[i, j] != 0:
                 mij_expr = expression_to_c(M[i, j])
                 yield f"    _sum += _x[{j}] * {mij_expr};"
-        yield fr"""    printf("r{i}= %e ", (_b[{i}] - _sum) / _b[{i}]);"""
+        yield rf"""    printf("r{i}= %e ", (_b[{i}] - _sum) / _b[{i}]);"""
     yield r"""    printf("\n");"""
     yield "}"
 
@@ -1185,8 +1185,8 @@ def main():
     rhs = Matrix(
         [
             -0.04 * y0 + 1e4 * y1 * y2,
-            0.04 * y0 - 1e4 * y1 * y2 - 3e7 * y1 ** 2,
-            3e7 * y1 ** 2,
+            0.04 * y0 - 1e4 * y1 * y2 - 3e7 * y1**2,
+            3e7 * y1**2,
         ]
     )
 
